@@ -1,24 +1,8 @@
-# The MIT License (MIT)
+# SPDX-FileCopyrightText: 2020 Jim Bennet for Adafruit Industries
+# SPDX-FileCopyrightText: 2020 Elena Horton for Adafruit Industries
 #
-# Copyright (c) 2020 Jim Bennett
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
+# SPDX-License-Identifier: MIT
+
 """
 `iot_mqtt`
 =====================
@@ -41,8 +25,7 @@ from . import constants
 
 # pylint: disable=R0903
 class IoTResponse:
-    """A response from a direct method call
-    """
+    """A response from a direct method call"""
 
     def __init__(self, code: int, message: str):
         """Creates an IoT Response object
@@ -54,8 +37,7 @@ class IoTResponse:
 
 
 class IoTMQTTCallback:
-    """An interface for classes that can be called by MQTT events
-    """
+    """An interface for classes that can be called by MQTT events"""
 
     def message_sent(self, data: str) -> None:
         """Called when a message is sent to the cloud
@@ -84,14 +66,21 @@ class IoTMQTTCallback:
         :param dict properties: The propreties sent with the mesage
         """
 
-    def device_twin_desired_updated(self, desired_property_name: str, desired_property_value, desired_version: int) -> None:
+    def device_twin_desired_updated(
+        self, desired_property_name: str, desired_property_value, desired_version: int
+    ) -> None:
         """Called when the device twin desired properties are updated
         :param str desired_property_name: The name of the desired property that was updated
         :param desired_property_value: The value of the desired property that was updated
         :param int desired_version: The version of the desired property that was updated
         """
 
-    def device_twin_reported_updated(self, reported_property_name: str, reported_property_value, reported_version: int) -> None:
+    def device_twin_reported_updated(
+        self,
+        reported_property_name: str,
+        reported_property_value,
+        reported_version: int,
+    ) -> None:
         """Called when the device twin reported values are updated
         :param str reported_property_name: The name of the reported property that was updated
         :param reported_property_value: The value of the reported property that was updated
@@ -101,17 +90,22 @@ class IoTMQTTCallback:
 
 # pylint: disable=R0902
 class IoTMQTT:
-    """MQTT client for Azure IoT
-    """
+    """MQTT client for Azure IoT"""
 
     def _gen_sas_token(self) -> str:
         token_expiry = int(time.time() + self._token_expires)
         uri = self._hostname + "%2Fdevices%2F" + self._device_id
-        signed_hmac_sha256 = compute_derived_symmetric_key(self._key, uri + "\n" + str(token_expiry))
+        signed_hmac_sha256 = compute_derived_symmetric_key(
+            self._key, uri + "\n" + str(token_expiry)
+        )
         signature = quote(signed_hmac_sha256, "~()*!.'")
-        if signature.endswith("\n"):  # somewhere along the crypto chain a newline is inserted
+        if signature.endswith(
+            "\n"
+        ):  # somewhere along the crypto chain a newline is inserted
             signature = signature[:-1]
-        token = "SharedAccessSignature sr={}&sig={}&se={}".format(uri, signature, token_expiry)
+        token = "SharedAccessSignature sr={}&sig={}&se={}".format(
+            uri, signature, token_expiry
+        )
         return token
 
     def _create_mqtt_client(self) -> None:
@@ -141,7 +135,12 @@ class IoTMQTT:
 
     # pylint: disable=C0103, W0613
     def _on_connect(self, client, userdata, _, rc) -> None:
-        self._logger.info("- iot_mqtt :: _on_connect :: rc = " + str(rc) + ", userdata = " + str(userdata))
+        self._logger.info(
+            "- iot_mqtt :: _on_connect :: rc = "
+            + str(rc)
+            + ", userdata = "
+            + str(userdata)
+        )
         if rc == 0:
             self._mqtt_connected = True
         self._auth_response_received = True
@@ -168,7 +167,9 @@ class IoTMQTT:
             self._callback.connection_status_change(False)
 
     def _on_publish(self, client, data, topic, msg_id) -> None:
-        self._logger.info("- iot_mqtt :: _on_publish :: " + str(data) + " on topic " + str(topic))
+        self._logger.info(
+            "- iot_mqtt :: _on_publish :: " + str(data) + " on topic " + str(topic)
+        )
 
     # pylint: disable=W0703
     def _handle_device_twin_update(self, client, topic: str, msg: str) -> None:
@@ -179,7 +180,12 @@ class IoTMQTT:
         try:
             twin = json.loads(msg)
         except json.JSONDecodeError as e:
-            self._logger.error("ERROR: JSON parse for Device Twin message object has failed. => " + msg + " => " + str(e))
+            self._logger.error(
+                "ERROR: JSON parse for Device Twin message object has failed. => "
+                + msg
+                + " => "
+                + str(e)
+            )
             return
 
         if "reported" in twin:
@@ -189,11 +195,15 @@ class IoTMQTT:
                 reported_version = reported["$version"]
                 reported.pop("$version")
             else:
-                self._logger.error("ERROR: Unexpected payload for reported twin update => " + msg)
+                self._logger.error(
+                    "ERROR: Unexpected payload for reported twin update => " + msg
+                )
                 return
 
             for property_name, value in reported.items():
-                self._callback.device_twin_reported_updated(property_name, value, reported_version)
+                self._callback.device_twin_reported_updated(
+                    property_name, value, reported_version
+                )
 
         is_patch = "desired" not in twin
 
@@ -206,11 +216,15 @@ class IoTMQTT:
             desired_version = desired["$version"]
             desired.pop("$version")
         else:
-            self._logger.error("ERROR: Unexpected payload for desired twin update => " + msg)
+            self._logger.error(
+                "ERROR: Unexpected payload for desired twin update => " + msg
+            )
             return
 
         for property_name, value in desired.items():
-            self._callback.device_twin_desired_updated(property_name, value, desired_version)
+            self._callback.device_twin_desired_updated(
+                property_name, value, desired_version
+            )
 
     def _handle_direct_method(self, client, topic: str, msg: str) -> None:
         index = topic.find("$rid=")
@@ -240,7 +254,14 @@ class IoTMQTT:
                 ret_message = json.dumps(ret_json)
 
         next_topic = "$iothub/methods/res/{}/?$rid={}".format(ret_code, method_id)
-        self._logger.info("C2D: => " + next_topic + " with data " + ret_message + " and name => " + method_name)
+        self._logger.info(
+            "C2D: => "
+            + next_topic
+            + " with data "
+            + ret_message
+            + " and name => "
+            + method_name
+        )
         self._send_common(next_topic, ret_message)
 
     def _handle_cloud_to_device_message(self, client, topic: str, msg: str) -> None:
@@ -275,7 +296,10 @@ class IoTMQTT:
                 self._logger.debug("Data sent")
                 break
             except RuntimeError as runtime_error:
-                self._logger.info("Could not send data, retrying after 0.5 seconds: " + str(runtime_error))
+                self._logger.info(
+                    "Could not send data, retrying after 0.5 seconds: "
+                    + str(runtime_error)
+                )
                 retry = retry + 1
 
                 if retry >= 10:
@@ -324,24 +348,34 @@ class IoTMQTT:
         self._hostname = hostname
         self._key = key
         self._token_expires = token_expires
-        self._username = "{}/{}/api-version={}".format(self._hostname, device_id, constants.IOTC_API_VERSION)
+        self._username = "{}/{}/api-version={}".format(
+            self._hostname, device_id, constants.IOTC_API_VERSION
+        )
         self._passwd = self._gen_sas_token()
         self._logger = logger if logger is not None else logging.getLogger("log")
         self._is_subscribed_to_twins = False
 
     def _subscribe_to_core_topics(self):
         device_bound_topic = "devices/{}/messages/devicebound/#".format(self._device_id)
-        self._mqtts.add_topic_callback(device_bound_topic, self._handle_cloud_to_device_message)
+        self._mqtts.add_topic_callback(
+            device_bound_topic, self._handle_cloud_to_device_message
+        )
         self._mqtts.subscribe(device_bound_topic)
 
         self._mqtts.add_topic_callback("$iothub/methods/#", self._handle_direct_method)
         self._mqtts.subscribe("$iothub/methods/#")
 
     def _subscribe_to_twin_topics(self):
-        self._mqtts.add_topic_callback("$iothub/twin/PATCH/properties/desired/#", self._handle_device_twin_update)
-        self._mqtts.subscribe("$iothub/twin/PATCH/properties/desired/#")  # twin desired property changes
+        self._mqtts.add_topic_callback(
+            "$iothub/twin/PATCH/properties/desired/#", self._handle_device_twin_update
+        )
+        self._mqtts.subscribe(
+            "$iothub/twin/PATCH/properties/desired/#"
+        )  # twin desired property changes
 
-        self._mqtts.add_topic_callback("$iothub/twin/res/200/#", self._handle_device_twin_update)
+        self._mqtts.add_topic_callback(
+            "$iothub/twin/res/200/#", self._handle_device_twin_update
+        )
         self._mqtts.subscribe("$iothub/twin/res/200/#")  # twin properties response
 
     def connect(self) -> bool:
@@ -357,7 +391,10 @@ class IoTMQTT:
         while self._auth_response_received is None:
             self.loop()
 
-        self._logger.info(" - iot_mqtt :: connect :: on_connect must be fired. Connected ? " + str(self.is_connected()))
+        self._logger.info(
+            " - iot_mqtt :: connect :: on_connect must be fired. Connected ? "
+            + str(self.is_connected())
+        )
         if not self.is_connected():
             return False
 
@@ -383,8 +420,7 @@ class IoTMQTT:
         self._is_subscribed_to_twins = True
 
     def disconnect(self) -> None:
-        """Disconnects from the MQTT broker
-        """
+        """Disconnects from the MQTT broker"""
         if not self.is_connected():
             return
 
@@ -393,8 +429,7 @@ class IoTMQTT:
         self._mqtts.disconnect()
 
     def reconnect(self) -> None:
-        """Reconnects to the MQTT broker
-        """
+        """Reconnects to the MQTT broker"""
         self._logger.info("- iot_mqtt :: reconnect :: ")
 
         self._mqtts.reconnect()
@@ -407,15 +442,16 @@ class IoTMQTT:
         return self._mqtt_connected
 
     def loop(self) -> None:
-        """Listens for MQTT messages
-        """
+        """Listens for MQTT messages"""
         if not self.is_connected():
             return
 
         self._mqtts.loop()
         gc.collect()
 
-    def send_device_to_cloud_message(self, message, system_properties: dict = None) -> None:
+    def send_device_to_cloud_message(
+        self, message, system_properties: dict = None
+    ) -> None:
         """Send a device to cloud message from this device to Azure IoT Hub
         :param message: The message data as a JSON string or a dictionary
         :param system_properties: System properties to send with the message
@@ -451,5 +487,7 @@ class IoTMQTT:
         :raises RuntimeError: if the internet connection is not responding or is unable to connect
         """
         self._logger.info("- iot_mqtt :: sendProperty :: " + str(patch))
-        topic = "$iothub/twin/PATCH/properties/reported/?$rid={}".format(int(time.time()))
+        topic = "$iothub/twin/PATCH/properties/reported/?$rid={}".format(
+            int(time.time())
+        )
         self._send_common(topic, patch)
